@Filename: TWd.s
@Part: ADuC7020,ADuC7024,ADuC7026.
@Created: 27/08/2004
@Updated: 28/06/2005
@Author: Barry Broderick
@This file is in beta sampling.

.include        "ADuC7020.equ"
.ARM

@ TWd==========Sets the watchdog mode switches of T3.
@ C Function prototype: int TWd(int iT, int iWd, int iSc, int iWdIrq);
@iT:{0,1,2,3}
@iWd:{0,1}
@iSc:{0,1}
@iWdIrq:{0,1}
@ Description of Function: Configures watchdog mode switches.
@ User interface: 
@   Set iT to desired Timer, 0 to 3
@   Set iWd to 1 to enable watchdog mode, else disable
@   Set iSc to 1 to enable secure clear option, else disable
@   Set iWdIrq to 1 to produce an IRQ instead of a reset when watchdog
@  reaches 0
@   Call TWd().
@       Timer 3 is stopped and the specified modes set.
@   Returns previous TCON value in r0.
@ Robustness:
@  Only works with T3. Will have no effect if used on other timers   
@ Side effects: Corrupts r1, r2, and r3.

.GLOBAL TWd
TWd:  
      mov      r1,r1,lsl#5          @LSL r1 and or it with r0
      orr      r1,r1,r2,lsl#4       @LSL r2 and or it with r0        
      orr      r1,r1,r3,lsl#1       @LSL r3 and or it with r0
   
      mov      r3,#0xff0000         @r3 = Z_BASE;
      orr      r3,r3,#0xff000000
      orr      r3,r3,r0,lsl#5       @r3 = r0 << 5;

      ldr      r2,[r3,#T0CON_OFFSET] @Load r4 with CON
      orr      r2,r2,r1              @OR r2 with r1
     
      ldr      r0,[r3,#T0CON_OFFSET] @Get CON.
      str      r2,[r3,#T0CON_OFFSET] @Write to CON
      bx       lr
